"""
pwd

Print the current working directory to standard output.
"""

import os


def main(*args):
    print(os.getcwd())
    return 0
